@@ -11,6 +11,10 @@ CONFIG = {
         "default": None,
         "help": "The key to encrypt the file with, if no key is passed a key will be generated and displayed on after the encrypted file is created",
     },
+    "acct_profile": {
+        "default": "default",
+        "help": "The default profile to use",
+        },
 }
 SUBCOMMANDS = {}
 DYNE = {
